python pitayaserver
====================

This lib helps creating pitaya backend servers using python.

### Installing

pip install pitayaserver

### Usage
For using the lib, you should assure that libpitaya-server compiled library is in the same path you are trying to run python, or specify it manually setting the env var PITAYA_LIB_DIR.

See python-example folder in root directory.
